@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::ben_and_jerry;
 use strict;
 use Acme::MetaSyntactic::MultiList;
 our @ISA = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 __PACKAGE__->init();
 
 my $regex = {
@@ -46,6 +46,12 @@ Abigail, Philippe Bruhat (BooK).
 
 =item *
 
+2013-02-18 - v1.004
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.030.
+
+=item *
+
 2012-11-12 - v1.003
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.027.
@@ -98,6 +104,7 @@ Bonnaroo_s_Coffee_Caramel_Buzz
 Boston_Cream_Pie
 Butter_Pecan
 Cake_Batter
+Candy_Bar_Pie
 Cannoli
 Cheesecake_Brownie
 Cherry_Garcia
@@ -124,6 +131,7 @@ Imagine_Whirled_Peace
 Karamel_Sutra
 Late_Night_Snack
 Lemonade_Sorbet
+Liz_Lemon
 Mango_Mango
 Milk_Cookies
 Mint_Chocolate_Chunk
